@@ -5,7 +5,7 @@ package Parse::AFP::IRD;
 use base 'Parse::AFP::Record';
 
 use constant SUBFORMAT => (
-    Data => 'a*',    # not yet parsed!
+    ImageData   => 'a*',
 );
 
 1;
